@@ -6,9 +6,7 @@ import os
 import requests
 
 import runpod.serverless.modules.logging as log
-from .worker_state import get_current_job_id, ping_url, ping_interval
-
-# COUNTER = 0
+from .worker_state import get_current_job_id, PING_URL, ping_interval
 
 
 def heartbeat_ping(session):
@@ -25,14 +23,18 @@ def heartbeat_ping(session):
                 'job_id': job_id,
             }
 
-            session.get(
-                ping_url,
+        if PING_URL not in [None, 'PING_URL_NOT_SET']:
+            result = session.get(
+                PING_URL,
                 params=ping_params,
                 timeout=int(ping_interval/1000)
             )
 
-        log.info(
-            f'Heartbeat sent to {ping_url} interval: {ping_interval}ms params: {ping_params}')
+            log.info(result)
+
+        log.info(f'Heartbeat URL: {PING_URL} Interval: {ping_interval}ms')
+        log.info(f"Heartbeat Params: {ping_params}")
+
     except Exception as err:  # pylint: disable=broad-except
         log.error(err)
 
@@ -41,10 +43,9 @@ def start_heartbeat():
     '''
     manages heartbeat timing
     '''
-
     session = requests.Session()
-    session.headers.update({
-        "Authorization": f"{os.environ.get('RUNPOD_AI_API_KEY')}"})
+    session.headers.update({"Authorization": f"{os.environ.get('RUNPOD_AI_API_KEY')}"})
+
     while True:
         heartbeat_ping(session)
         time.sleep(ping_interval/1000)
